pub enum ConfigurationStruct {
Show 21 variants
AggregateConfiguration,
ContainerdConfiguration,
DatadogApmStatsEncoderConfiguration,
DatadogEventsConfiguration,
DatadogLogsConfiguration,
DatadogMetricsConfiguration,
DatadogServiceChecksConfiguration,
DatadogTraceConfiguration,
DogStatsDConfiguration,
DogStatsDDebugLogConfiguration,
DogStatsDMapperConfiguration,
DogStatsDPrefixFilterConfiguration,
ForwarderConfiguration,
MrfConfiguration,
ProxyConfiguration,
RemoteAgentClientConfiguration,
TagFilterlistConfiguration,
TraceObfuscationConfiguration,
TypedConfigSystem,
GetTyped,
NoSmoke,
}Expand description
A configuration consumer tracked by the legacy smoke-test registry.
Most variants name structs that consume Agent configuration directly. Sentinel variants track consumers that do not fit the legacy deserialization test model.
Variants
AggregateConfiguration
ContainerdConfiguration
DatadogApmStatsEncoderConfiguration
DatadogEventsConfiguration
DatadogLogsConfiguration
DatadogMetricsConfiguration
DatadogServiceChecksConfiguration
DatadogTraceConfiguration
DogStatsDConfiguration
DogStatsDDebugLogConfiguration
DogStatsDMapperConfiguration
DogStatsDPrefixFilterConfiguration
ForwarderConfiguration
MrfConfiguration
ProxyConfiguration
RemoteAgentClientConfiguration
TagFilterlistConfiguration
TraceObfuscationConfiguration
TypedConfigSystem
Keys consumed through the typed configuration translation system.
GetTyped
Keys read via get_typed / try_get_typed rather than struct deserialization.
NoSmoke
Sentinel for supported keys that are being promoted during the transition to typed-configuration access. These were missing from our inventory when config smoke testing was introduced and for various reasons may not be legitimate targets for that testing modality. Regardless, these fields will be part of the typed translation system and this sentinel can be removed when our testing model moves over to that system.
Implementations
Sourceimpl ConfigurationStruct
impl ConfigurationStruct
Sourcepub fn as_smoke_test_const(&self) -> &'static str
pub fn as_smoke_test_const(&self) -> &'static str
Apparently we travel back and forth between string constant representation and the struct names themselves. This function recovers the string constant name for a struct.