ConfigurationStruct

Enum ConfigurationStruct 

pub enum ConfigurationStruct {
Show 22 variants AggregateConfiguration, ContainerdConfiguration, DatadogApmStatsEncoderConfiguration, DatadogEventsConfiguration, DatadogLogsConfiguration, DatadogMetricsConfiguration, DatadogServiceChecksConfiguration, DatadogTraceConfiguration, DogStatsDConfiguration, DogStatsDDebugLogConfiguration, DogStatsDMapperConfiguration, DogStatsDPrefixFilterConfiguration, ForwarderConfiguration, MrfConfiguration, OtlpConfiguration, OtlpDecoderConfiguration, OtlpRelayConfiguration, ProxyConfiguration, RemoteAgentClientConfiguration, TagFilterlistConfiguration, TraceObfuscationConfiguration, GetTyped,
}
A struct in the Saluki repository that deserializes Datadog Agent configuration.

Used as values in schema_overlay.yaml used_by fields to declare which structs consume a given key. Adding a new struct here is the first step when registering its configuration keys.

This construct has been carried over from the original config_registry in order to support configuration smoke test code generation. Each variant in this enum should be an exact name match to a struct that consumes its value directly from Agent configuration either by deserializing or by environment variable.

Variants



AggregateConfiguration



ContainerdConfiguration



DatadogApmStatsEncoderConfiguration



DatadogEventsConfiguration



DatadogLogsConfiguration



DatadogMetricsConfiguration



DatadogServiceChecksConfiguration



DatadogTraceConfiguration



DogStatsDConfiguration



DogStatsDDebugLogConfiguration



DogStatsDMapperConfiguration



DogStatsDPrefixFilterConfiguration



ForwarderConfiguration



MrfConfiguration



OtlpConfiguration



OtlpDecoderConfiguration



OtlpRelayConfiguration



ProxyConfiguration



RemoteAgentClientConfiguration



TagFilterlistConfiguration



TraceObfuscationConfiguration



GetTyped

Keys read via get_typed / try_get_typed rather than struct deserialization.

Implementations

Source

impl ConfigurationStruct

pub fn as_smoke_test_const(&self) -> &'static str

Apparently we travel back and forth between string constant representation and the struct names themselves. This function recovers the string constant name for a struct.